/* utils.js javascript*/

function createMap() 
{
	  OpenLayers.Lang.setCode('de');
		
		var projmerc = new OpenLayers.Projection("EPSG:900913");
		var proj4326 = new OpenLayers.Projection("EPSG:4326");

    var map = new OpenLayers.Map('map', {
        projection: projmerc, displayProjection: proj4326, controls: [
            new OpenLayers.Control.Navigation(),
            new OpenLayers.Control.Attribution(),
            new OpenLayers.Control.LayerSwitcher(),
            new OpenLayers.Control.Permalink('permalink'),
            new OpenLayers.Control.OverviewMap(),
            new OpenLayers.Control.PanZoomBar(),
            new OpenLayers.Control.ScaleLine({maxWidth:200})
        ],
        maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34, 20037508.34, 20037508.34),
        numZoomLevels: 18, maxResolution: 156543, units: 'm' });
    
    // Base Layer:
    var l_mapnik = new OpenLayers.Layer.OSM.Mapnik("Mapnik (Standard)", { attribution: '', keyname: 'mapnik' });
    var l_osmarender = new OpenLayers.Layer.OSM.Osmarender("Osmarender", { attribution: '', keyname: 'osmarender' });
    var l_cyclemap = new OpenLayers.Layer.OSM.CycleMap("Cycle Map (Höhenlinien)", { attribution: '', keyname: 'CycleMap' });
    var l_hillshading = new OpenLayers.Layer.TMS("Hillshading (NASA SRTM3 v2)","http://toolserver.org/~cmarqu/hill/",
                        {type: 'png', getURL: osm_getTileURL,displayOutsideMaxExtent: true, isBaseLayer: false,
	                       transparent: true, opacity: 0.9999999999, "visibility": false});
    var l_nix = new OpenLayers.Layer.XYZ("Keine Karte", "http://tile.openstreetmap.org/osm/${z}/${x}/${y}.png", {attribution: 'Karte', keyname: 'mapnik'});

    map.addLayers([l_mapnik, l_osmarender, l_cyclemap, l_hillshading]);

    var lonlat = new OpenLayers.LonLat(lon, lat);
    lonlat.transform(map.displayProjection,  map.projection);
    map.setCenter(lonlat, zoom);
    
    // createTracks(map); // activate for using tracks
    createLayers(map);
    createMarkers(map);
    
} // end createMap()

function osm_getTileURL(bounds) 
{
		var res = this.map.getResolution();
		var x = Math.round((bounds.left - this.maxExtent.left) / (res * this.tileSize.w));
		var y = Math.round((this.maxExtent.top - bounds.top) / (res * this.tileSize.h));
		var z = this.map.getZoom();
		var limit = Math.pow(2, z);

		if (y < 0 || y >= limit) {
				return OpenLayers.Util.getImagesLocation() + "404.png";
		} else {
				x = ((x % limit) + limit) % limit;
				return this.url + z + "/" + x + "/" + y + "." + this.type;
		}
}


function newIcon(url, x, y) 
{
    var size = new OpenLayers.Size(x, y);
    var offset = new OpenLayers.Pixel(-(size.w/2), -(size.h/2));
    return new OpenLayers.Icon(url, size, offset);
}

function addMarker(map, layer, icon_url, size, offset, lon, lat, popupContentHTML) 
{
    var lonlat = new OpenLayers.LonLat(lon, lat);
    lonlat.transform(map.displayProjection,  map.projection);

    var feature = new OpenLayers.Feature(layer, lonlat); 
    feature.closeBox = true;
    feature.popupClass = OpenLayers.Class(OpenLayers.Popup.FramedCloud, {'autoSize': true}  );
     // feature.popupClass = OpenLayers.Class(OpenLayers.Popup.FramedCloud, {minSize: new OpenLayers.Size(300, 180) } );
    feature.data.popupContentHTML = popupContentHTML;
    feature.data.overflow = "hidden";

    var icon = newIcon(icon_url, size, offset);            

    var marker = new OpenLayers.Marker(lonlat, icon.clone());
    marker.feature = feature;

    var markerClick = function(evt) {
        if (this.popup == null) {
            this.popup = this.createPopup(this.closeBox);
            map.addPopup(this.popup);
            this.popup.show();
        } else {
            this.popup.toggle();
        }
        OpenLayers.Event.stop(evt);
    };
    marker.events.register("mousedown", feature, markerClick);

    layer.addMarker(marker);
}
